[PATCH 30/37] mi: Shortcut miCopyArea based on paintable not realized

Adam Jackson ajax at redhat.com
Wed Oct 8 08:04:54 PDT 2014


Signed-off-by: Adam Jackson <ajax at redhat.com>
---
 mi/mibitblt.c | 4 ++--
 1 file changed, 2 insertions(+), 2 deletions(-)

diff --git a/mi/mibitblt.c b/mi/mibitblt.c
index 08bd1c5..391fb01 100644
--- a/mi/mibitblt.c
+++ b/mi/mibitblt.c
@@ -96,9 +96,9 @@ miCopyArea(DrawablePtr pSrcDrawable,
     srcx = xIn + pSrcDrawable->x;
     srcy = yIn + pSrcDrawable->y;
 
     /* If the destination isn't realized, this is easy */
     if (pDstDrawable->type == DRAWABLE_WINDOW &&
-        !((WindowPtr) pDstDrawable)->realized)
+        !((WindowPtr) pDstDrawable)->paintable)
         return NULL;
 
     /* clip the source */
@@ -96,9 +96,9 @@ miCopyArea(DrawablePtr pSrcDrawable,
     srcy = yIn + pSrcDrawable->y;
 
-    /* If the destination isn't realized, this is easy */
+    /* If the destination isn't paintable, this is easy */
     if (pDstDrawable->type == DRAWABLE_WINDOW &&
-- 
1.9.3



More information about the xorg-devel mailing list